@@ -69,6 +69,7 @@ class GitlabTest(unittest.TestCase):
         assert isinstance(self.git.getprojects(page=5), list)
         assert isinstance(self.git.getprojects(per_page=7), list)
         assert isinstance(self.git.getproject(self.project_id), dict)
+        assert isinstance(self.git.getproject(self.project['path_with_namespace']), dict)
         self.assertFalse(self.git.getproject("wrong"))
 
         # test getprojectsall
@@ -226,7 +227,7 @@ class GitlabTest(unittest.TestCase):
         self.assertNotEqual(firstfile["commit_id"], secondfile["commit_id"])
         self.assertNotEqual(firstfile["content"], secondfile["content"])
         self.assertTrue(self.git.deletefile(self.project_id, "test.file", "develop", "remove_testfile"))
-        assert isinstance(self.git.getcontributors(self.project_id), list)
+        assert self.git.getcontributors(self.project_id) is not False
 
     def test_search(self):
         self.assertGreater(len(self.git.searchproject(self.project['name'])), 0)
@@ -245,8 +246,13 @@ class GitlabTest(unittest.TestCase):
         assert isinstance(self.git.getgroups(), list)
         group = self.git.getgroups()[0]
         assert isinstance(self.git.getgroupmembers(group["id"]), list)
-        self.assertEqual(len(self.git.getgroupmembers(group["id"])), 0)
-        self.assertTrue(self.git.addgroupmember(group["id"], self.user_id, "master"))
+        try:
+            # Gitlab < 7.8
+            self.assertEqual(len(self.git.getgroupmembers(group["id"])), 0)
+            self.assertTrue(self.git.addgroupmember(group["id"], self.user_id, "master"))
+        except AssertionError:
+            # In Gitlab > 7.7, Admin is automatically added to all groups. Keep breaking that api champs.
+            self.assertEqual(len(self.git.getgroupmembers(group["id"])), 1)
         assert isinstance(self.git.getgroupmembers(group["id"]), list)
         self.assertGreater(len(self.git.getgroupmembers(group["id"])), 0)
         self.assertTrue(self.git.deletegroupmember(group["id"], self.user_id))
@@ -346,8 +352,7 @@ class GitlabTest(unittest.TestCase):
         labels = self.git.getlabels(self.project_id)
         assert isinstance(labels, list)
         self.assertEqual(len(labels), 0)
-        newlabel = self.git.createlabel(self.project_id, "test_label", "#FFAABB")
-        assert isinstance(newlabel, dict)
+        assert self.git.createlabel(self.project_id, "test_label", "#FFAABB") is not False
         labels = self.git.getlabels(self.project_id)
         self.assertEqual(len(labels), 1)
         self.assertTrue(self.git.deletelabel(self.project_id, "test_label"))
